<!-- markdownlint-disable -->



# <kbd>module</kbd> `utils`






---



## <kbd>class</kbd> `ToolUtils`
Class containing utility methods. 




---



### <kbd>method</kbd> `hash_str`

```python
hash_str(string_to_hash: str, hash_method: str = 'md5') → str
```

Computes the hash for a given input string. 

Useful to hash strings needed for caching and other purposes. Hash method defaults to "md5" 



**Args:**
 
 - <b>`string_to_hash`</b> (str):  String to be hashed 
 - <b>`hash_method`</b> (str):  Hash hash_method to use, supported ones 
        - "md5" 



**Returns:**
 
 - <b>`str`</b>:  Hashed string 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
